"""Fixes for CNRM-ESM2-1 model."""
from .cnrm_cm6_1 import Cl as BaseCl
from .cnrm_cm6_1 import Clcalipso as BaseClcalipso
from .cnrm_cm6_1 import Cli as BaseCli
from .cnrm_cm6_1 import Clw as BaseClw
from .cnrm_cm6_1 import Omon as BaseOmon


Cl = BaseCl


Clcalipso = BaseClcalipso


Cli = BaseCli


Clw = BaseClw


Omon = BaseOmon
